@@ -20,7 +20,6 @@ import os
 from __caspo__ import cno, args, utils, Network, Dataset, Learner
 
 if __name__ == '__main__':
-    profiler = utils.Profiler()
     arguments = args.get_args()
 
     print '\nReading input files...'
@@ -32,14 +31,19 @@ if __name__ == '__main__':
     print 'done.'
     
     learner = Learner(network, dataset)
-    profiler.start()
+    
+    clasp = dict(optimal="",suboptimal="")
+    if arguments.clasp:
+        clasp["optimal"] = arguments.clasp.readline()[:-1]
+        clasp["suboptimal"] = arguments.clasp.readline()[:-1]
+        
     if arguments.gtts:
         print '\nLearning Boolean logic models and their Global Truth Tables with ASP...',
     else:
         print '\nLearning Boolean logic models with ASP...',
-
-    family = learner.learn(arguments.fit, arguments.size, arguments.discrete, arguments.gtts)
-    print 'done in %s sec.' % profiler.stop()
+        
+    family = learner.learn(arguments.fit, arguments.size, arguments.discrete, arguments.gtts, clasp)
+    print 'done.'
     
     if arguments.gtts:
         print "%s Boolean logic models and %s Global Truth Tables have been learned.\n" % (len(family), len(family.gtts))
@@ -76,7 +80,7 @@ if __name__ == '__main__':
         kfolds = arguments.cross[1]
         
         print '\nRunning %s random %s-fold cross validation... ' % (times, kfolds)
-        results = learner.validate(arguments.fit, arguments.size, arguments.discrete, times, kfolds)
+        results = learner.validate(arguments.fit, arguments.size, arguments.discrete, times, kfolds, clasp)
         for i,res in enumerate(results):
             writer.write(res, 'cross_validation_%s.csv' % (i+1), ['gtts', 'mse', 'models'])
 
