@@ -15,11 +15,25 @@
 # You should have received a copy of the GNU General Public License
 # along with caspo.  If not, see <http://www.gnu.org/licenses/>.import random
 # -*- coding: utf-8 -*-
-
+import os
 from cellnopt.wrapper import *
 
-def compress(pkn, midas, compr):
+def compress(pkn, midas):
+    """
+    Compress a PKN with respect to a MIDAS file using CellNOpt. 
+    Returns the SIF filepath to the compressed PKN
+    
+    :param pkn: PKN sif filepath
+    :param midas: MIDAS filepath
+    :returns: string
+    """
+    temp = ".compr_model.sif"
+    if os.path.exists(temp):
+        os.remove(temp)
+    
     cnolist = CNOlist(midas)
     pknmodel = readSIF(pkn)        
     model = preprocessing(cnolist, pknmodel, expansion=False)
-    writeSIF(model, compr)
\ No newline at end of file
+    writeSIF(model, temp)
+    
+    return temp
\ No newline at end of file
